// Soft start sequencer for ATTINY25
// 2015 DogMouth

#include <avr/interrupt.h>    // Defines pins, ports, etc
#include <stdlib.h>
#include <avr/io.h>
#define F_CPU 1000000UL	      // Sets up the default speed for delay.h
#include <util/delay.h>

int steptime;
int numsteps;
const int maxdelay=3000;
const int mindelay=500;
const int deadtime=100;

void softdelay(void); 

////////////////////////////////////////////////////////////////
// run delay loop to avoid float penalty for variable time delays

void softdelay(void){
	_delay_ms(mindelay);

	int steptime = (maxdelay-mindelay)/255;
	int numsteps = ADCH; 
	
	for (int x=0; x <= numsteps; x++){
		_delay_ms(steptime);
	}

	return;
}

////////////////////////////////////////////////////////////////
int main(void){
	// device and routine setup goes here
	ADCSRA |= (1 << ADPS2) | (1 << ADPS1); // | (1 << ADPS0); //set prescaling
	ADCSRA |= (1 << ADATE); //put ADC into auto triggered mode
	ADCSRB &= 0xF8; //set trigger source to free running
	ADMUX &= 0x0F; //set reference mux to VCC
	ADMUX |= (1 << ADLAR); //left-adjust to easily convert to 8-bit resolution
	
	//this enables the adc and begins free running conversion
	ADCSRA |= (1 << ADEN) | (1 << ADSC); 
	
	//set direction register for outputs on pin 6 and 0 (D0=OC0B)
	DDRB |= (1 << PB1) | (1 << PB0); 

	//check ADC
	ADMUX = (ADMUX & 0xf0) | 0x03; //select ADC3 PIN 2
	
	//do port sequencing
	PORTB = (PORTB & 0xf0) | 0x01; 	//set HV output
	softdelay();
	PORTB = (PORTB & 0xf0); 	//blank output
	_delay_ms(deadtime);
	PORTB = (PORTB & 0xf0) | 0x02; 	//set LV output

	return(0);
}









